The Values System
=================

.. contents::
   :depth: 2
   :local:
   :backlinks: none

Outline
-------
 - What problem is the values system trying to solve?
 - The difference between
 - Specifying defaults.
